@@ -2,11 +2,13 @@
 sentry.plugins.helpers
 ~~~~~~~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
 
-from sentry.models import ProjectOption, Option, UserOption
+from sentry import options
+from sentry.models import ProjectOption, UserOption
 
 __all__ = ('set_option', 'get_option', 'unset_option')
 
@@ -17,10 +19,9 @@ def reset_options(prefix, project=None, user=None):
         UserOption.objects.clear_cache()
     elif project:
         ProjectOption.objects.filter(key__startswith='%s:' % (prefix,), project=project).delete()
-        ProjectOption.objects.clear_cache()
+        ProjectOption.objects.clear_local_cache()
     else:
-        Option.objects.filter(key__startswith='%s:' % (prefix,)).delete()
-        Option.objects.clear_cache()
+        raise NotImplementedError
 
 
 def set_option(key, value, project=None, user=None):
@@ -29,7 +30,7 @@ def set_option(key, value, project=None, user=None):
     elif project:
         result = ProjectOption.objects.set_value(project, key, value)
     else:
-        result = Option.objects.set_value(key, value)
+        raise NotImplementedError
 
     return result
 
@@ -40,7 +41,7 @@ def get_option(key, project=None, user=None):
     elif project:
         result = ProjectOption.objects.get_value(project, key, None)
     else:
-        result = Option.objects.get_value(key, None)
+        result = options.get(key)
 
     return result
 
@@ -51,6 +52,6 @@ def unset_option(key, project=None, user=None):
     elif project:
         result = ProjectOption.objects.unset_value(project, key)
     else:
-        result = Option.objects.unset_value(key)
+        raise NotImplementedError
 
     return result
