@@ -2,20 +2,22 @@
 sentry.web.forms
 ~~~~~~~~~~~~~~~~
 
-:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2014 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
+from __future__ import absolute_import
+
 from django import forms
 from django.utils.translation import ugettext_lazy as _
 
-from sentry.interfaces import Http
+from sentry.constants import HTTP_METHODS
 from sentry.models import User, Activity
-from sentry.web.forms.fields import RadioFieldRenderer
+from sentry.web.forms.fields import RadioFieldRenderer, ReadOnlyTextField
 
 
 class ReplayForm(forms.Form):
     url = forms.URLField(widget=forms.TextInput(attrs={'class': 'span8'}))
-    method = forms.ChoiceField(choices=((k, k) for k in Http.METHODS))
+    method = forms.ChoiceField(choices=((k, k) for k in HTTP_METHODS))
     data = forms.CharField(required=False, widget=forms.Textarea(attrs={'class': 'span8'}))
     headers = forms.CharField(required=False, widget=forms.Textarea(attrs={'class': 'span8'}))
 
@@ -24,7 +26,7 @@ class ReplayForm(forms.Form):
         if not value:
             return
 
-        return dict(line.split(': ') for line in value.splitlines())
+        return dict(line.split(': ', 1) for line in value.splitlines())
 
 
 class BaseUserForm(forms.ModelForm):
@@ -46,11 +48,26 @@ class NewUserForm(BaseUserForm):
 class ChangeUserForm(BaseUserForm):
     is_staff = forms.BooleanField(required=False, label=_('Admin'),
         help_text=_("Designates whether this user can perform administrative functions."))
+    is_superuser = forms.BooleanField(required=False, label=_('Superuser'),
+        help_text=_('Designates whether this user has all permissions without '
+                    'explicitly assigning them.'))
 
     class Meta:
-        fields = ('first_name', 'username', 'email', 'is_active', 'is_staff')
+        fields = ('first_name', 'username', 'email', 'is_active', 'is_staff',
+                  'is_superuser')
         model = User
 
+    def __init__(self, *args, **kwargs):
+        super(ChangeUserForm, self).__init__(*args, **kwargs)
+        self.user = kwargs['instance']
+        if self.user.is_managed:
+            self.fields['username'] = ReadOnlyTextField(label="Username (managed)")
+
+    def clean_username(self):
+        if self.user.is_managed:
+            return self.user.username
+        return self.cleaned_data['username']
+
 
 class RemoveUserForm(forms.Form):
     removal_type = forms.ChoiceField(choices=(
